@@ -4,7 +4,7 @@
  * Curses functions for MP3info
  *
  * Author:
- *       Ricardo Cerqueira	<rmc@ssi.aaum.pt>
+ *       Ricardo Cerqueira	<rmc@rccn.net>
  *
  * This software is covered by the GNU public license, which should be in a file named
  * LICENSE acompanying this.
@@ -18,7 +18,7 @@
  */
 
 char *checkinput(int c, char *string, int length) {
-        if (c == CTRL_C) { endwin(); exit(); }
+        if (c == CTRL_C) { endwin(); exit(0); }
         pad(string,length);
         return string;
 }
@@ -51,7 +51,7 @@ WINDOW *mainwin;
    intrflush(mainwin, FALSE);
    keypad(mainwin, TRUE);
    CenterText(1,VERSION);
-   CenterText(2,"Ricardo Cerqueira <rmc@ssi.aaum.pt>, 1999");
+   CenterText(2,"Ricardo Cerqueira <rmc@rccn.net>, 1999");
 #ifdef HAVE_TOUCHWIN
    touchwin(mainwin);
 #endif
