@@ -4,7 +4,7 @@
  * MP3info's main file. MP3info is an ID3 tag editor.
  *
  * Author:
- *       Ricardo Cerqueira	<rmc@ssi.aaum.pt>
+ *       Ricardo Cerqueira	<rmc@rccn.net>
  *
  * This software is covered by the GNU public license, which should be in a file named
  * LICENSE acompanying this.
@@ -18,6 +18,7 @@ int main(int argc, char *argv[]) {
 FILE  *fp;
 int c, interactive = 0;
 char fullline[128], title[31]="", artist[31]="", album[31]="", year[5]="", comment[31]="", fbuf[4];
+unsigned short sig;
 
    if (argc < 2 ) /* Only command is given. Short help */ {
 	   printf("%s\r\n  Usage: %s [-h] (-i | -t title -a artist -l album -y year -c comment ) 
@@ -34,7 +35,18 @@ char fullline[128], title[31]="", artist[31]="", album[31]="", year[5]="", comme
            perror("Error opening MP3");
            return 0;
    }
-  
+
+   /* Let's see if it's an MP3. SMJ 06/1999 */     
+
+   fread(&sig,sizeof(short),1,fp);                         
+   sig &= 0xf0ff;                                                         
+   if(sig != 0xf0ff) {
+           fprintf(stderr,"%s is not an MP3 file!\n",argv[argc-1]);        
+           return(-1);
+   }                                                          
+
+   
+ 
    /* Go to EOF and check if there's already a tag */
 
    if ( fseek(fp, -128, SEEK_END )) { return 0; }
@@ -54,6 +66,11 @@ char fullline[128], title[31]="", artist[31]="", album[31]="", year[5]="", comme
 	   /* No tags here. Back to the EOF to append the new one */
 	   fseek(fp, 0, SEEK_END); 
    }
+       
+   if(argc==2) {                                                          
+           view_tag(fp);
+           return(0);        
+   }
   
    /* Let's see what the user wants to do... */
    while ((c=getopt(argc,argv,"vhit:a:l:y:c:"))!=-1) {
