@@ -2,7 +2,7 @@
  *  mp3info.h
  *  
  *  Author:
- *        Ricardo Cerqueira      <rmc@ssi.aaum.pt>
+ *        Ricardo Cerqueira      <rmc@rccn.net>
  *    
  *  This software is covered by the GNU public license, which should be in a file named
  *  LICENSE acompanying this.
@@ -13,11 +13,11 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <ctype.h>
-#include <strings.h>
+#include <string.h>
 #include <curses.h>
 #include <signal.h>
 #include "textfunc.h"
 
-#define VERSION "MP3info - v0.3.1"
+#define VERSION "MP3info - v0.4.0"
 
 void tagedit_curs(FILE *fp, char *filename, char *line);
